diff --git a/google_tag.module b/google_tag.module
index 82ab7f0ed..c01f5d946 100644
--- a/google_tag.module
+++ b/google_tag.module
@@ -224,10 +224,13 @@ function google_tag_page_build(&$page) {
 /**
  * Returns applicable realm name and key for the request.
  *
+ * @param bool $append_path
+ *   Add to path the trailing slash and dot.
+ *
  * @return array
  *   The realm name and key.
  */
-function google_tag_realm_values() {
+function google_tag_realm_values($append_path = TRUE) {
   $realm_name = $realm_key = '';
 
   if (module_exists('variable_realm') && module_exists('variable_store')) {
@@ -257,7 +260,16 @@ function google_tag_realm_values() {
 
     $debug = variable_get('google_tag_debug_output', 0);
     $debug ? drupal_set_message(t('realm:key = @realm:@key', array('@realm' => $realm_name, '@key' => $realm_key))) : '';
-
+  }
+  // If domain_conf is enabled, use domain as realm fallback.
+  elseif (module_exists('domain_conf')) {
+    global $_domain;
+    if (!empty($_domain) && isset($_domain['domain_id'])) {
+      $realm_key = ((string) $_domain['domain_id']);
+      $realm_name = $_domain['machine_name'];
+    }
+  }
+  if ($append_path) {
     $realm_name .= $realm_name ? '/' : '';
     $realm_key .= $realm_key ? '.' : '';
   }
diff --git a/includes/admin.inc b/includes/admin.inc
index bf1ac461a..ef0a216d0 100644
--- a/includes/admin.inc
+++ b/includes/admin.inc
@@ -180,6 +180,15 @@ function google_tag_settings_form_submit($form, &$form_state) {
   if (!empty($form['#realm_keys'])) {
     $realm_name = key($form['#realm_keys']);
     $realm_key = current($form['#realm_keys']);
+  }
+  else {
+    // Check for domain conf.
+    if (module_exists('domain_conf')) {
+      list($realm_name, $realm_key) = google_tag_realm_values(FALSE);
+    }
+  }
+
+  if (!empty($realm_name)) {
     _google_tag_prepare_directory($realm_name);
   }
